==> webkitgtk-2.13.2.tar.xz: webkitgtk-2.13.2/Source/JavaScriptCore/builtins/ArrayIteratorPrototype.js <==
/*
 * Copyright (C) 2015 Yusuke Suzuki <utatane.tea@gmail.com>.
 * Copyright (C) 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

function next()
{
    "use strict";

    if (this == null) {
        if (this === null)
            throw new @TypeError("%ArrayIteratorPrototype%.next requires that |this| not be null");
        throw new @TypeError("%ArrayIteratorPrototype%.next requires that |this| not be undefined");
    }

    let next = this.@arrayIteratorNext;
    if (next === @undefined)
        throw new @TypeError("%ArrayIteratorPrototype%.next requires that |this| be an Array Iterator instance");

    return next.@call(this);
}

@globalPrivate
function arrayIteratorValueNext()
{
    "use strict";
    var done = true;
    var value;

    var array = this.@iteratedObject;
    if (!this.@arrayIteratorIsDone) {
        var index = this.@arrayIteratorNextIndex;
        var length = array.length >>> 0;
        if (index >= length) {
            this.@arrayIteratorIsDone = true;
        } else {
            this.@arrayIteratorNextIndex = index + 1;
            done = false;
            value = array[index];
        }
    }

    return { done, value };
}

@globalPrivate
function arrayIteratorKeyNext()
{
    "use strict";
    var done = true;
    var value;

    var array = this.@iteratedObject;
    if (!this.@arrayIteratorIsDone) {
        var index = this.@arrayIteratorNextIndex;
        var length = array.length >>> 0;
        if (index >= length) {
            this.@arrayIteratorIsDone = true;
        } else {
            this.@arrayIteratorNextIndex = index + 1;
            done = false;
            value = index;
        }
    }

    return { done, value };
}

@globalPrivate
function arrayIteratorKeyValueNext()
{
    "use strict";
    var done = true;
    var value;

    var array = this.@iteratedObject;
    if (!this.@arrayIteratorIsDone) {
        var index = this.@arrayIteratorNextIndex;
        var length = array.length >>> 0;
        if (index >= length) {
            this.@arrayIteratorIsDone = true;
        } else {
            this.@arrayIteratorNextIndex = index + 1;
            done = false;
            value = [ index, array[index] ];
        }
    }

    return { done, value };
}

==> webkitgtk-2.14.2.tar.xz: webkitgtk-2.14.2/Source/JavaScriptCore/builtins/ArrayIteratorPrototype.js <==
/*
 * Copyright (C) 2015 Yusuke Suzuki <utatane.tea@gmail.com>.
 * Copyright (C) 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

function next()
{
    "use strict";

    if (this == null)
        throw new @TypeError("%ArrayIteratorPrototype%.next requires that |this| not be null or undefined");

    let next = this.@arrayIteratorNext;
    if (next === @undefined)
        throw new @TypeError("%ArrayIteratorPrototype%.next requires that |this| be an Array Iterator instance");

    return next.@call(this);
}

@globalPrivate
function arrayIteratorValueNext()
{
    "use strict";
    var done = true;
    var value;

    var array = this.@iteratedObject;
    if (!this.@arrayIteratorIsDone) {
        var index = this.@arrayIteratorNextIndex;
        var length = array.length >>> 0;
        if (index >= length) {
            this.@arrayIteratorIsDone = true;
        } else {
            this.@arrayIteratorNextIndex = index + 1;
            done = false;
            value = array[index];
        }
    }

    return { done, value };
}

@globalPrivate
function arrayIteratorKeyNext()
{
    "use strict";
    var done = true;
    var value;

    var array = this.@iteratedObject;
    if (!this.@arrayIteratorIsDone) {
        var index = this.@arrayIteratorNextIndex;
        var length = array.length >>> 0;
        if (index >= length) {
            this.@arrayIteratorIsDone = true;
        } else {
            this.@arrayIteratorNextIndex = index + 1;
            done = false;
            value = index;
        }
    }

    return { done, value };
}

@globalPrivate
function arrayIteratorKeyValueNext()
{
    "use strict";
    var done = true;
    var value;

    var array = this.@iteratedObject;
    if (!this.@arrayIteratorIsDone) {
        var index = this.@arrayIteratorNextIndex;
        var length = array.length >>> 0;
        if (index >= length) {
            this.@arrayIteratorIsDone = true;
        } else {
            this.@arrayIteratorNextIndex = index + 1;
            done = false;
            value = [ index, array[index] ];
        }
    }

    return { done, value };
}
